@@ -4,7 +4,6 @@ from openride.core.rotation import Rotation
 from openride.core.size import Size
 from openride.core.transform import Transform
 from openride.core.numba.box_utils import bev_box_vertices, box_vertices
-from openride.core.numba.transforms import rotation_matrix
 
 from dataclasses import dataclass
 from shapely import geometry
@@ -16,7 +15,7 @@ import numpy as np
 @dataclass
 class BoundingBox(Geometry):
 
-    position: Point = Point()
+    position: Point = Point(0,0,0)
     rotation: Rotation = Rotation()
     size: Size = Size()
 
@@ -28,11 +27,7 @@ class BoundingBox(Geometry):
     def transform(self, transform:'Transform') -> 'BoundingBox':
         return BoundingBox(
             self.position.transform(transform), 
-            Rotation(
-                self.rotation.roll + transform.rotation.roll, 
-                self.rotation.pitch + transform.rotation.pitch, 
-                self.rotation.yaw + transform.rotation.yaw
-            ), 
+            self.rotation + transform.rotation,
             self.size,
         )
 
@@ -42,11 +37,12 @@ class BoundingBox(Geometry):
 
 
     def get_bird_eye_view_vertices(self) -> np.ndarray:
-        return bev_box_vertices(self.position.x, self.position.y, self.size.x, self.size.y, rotation_matrix(0,0,-self.rotation.yaw))
+        return bev_box_vertices(self.position.x, self.position.y, self.size.x, self.size.y, self.rotation.yaw)
 
 
     def get_vertices(self) -> np.ndarray:
         return box_vertices(
             self.position.x, self.position.y, self.position.z, 
-            self.size.x, self.size.y, self.size.z, self.rotation.matrix,
+            self.size.x, self.size.y, self.size.z, 
+            self.rotation.roll, self.rotation.pitch, self.rotation.yaw,
         )
