@@ -14,7 +14,7 @@ class Collection(ABC):
 
     @abstractclassmethod
     def append(self, obj:Any):
-        """Add an object to hte collection"""
+        """Add an object to the collection"""
 
 
     @abstractclassmethod
