@@ -5,7 +5,6 @@ from openride.core.numba.transforms import transform_vertices
 
 from typing import List, Union
 
-import copy
 import numpy as np
 
 
@@ -50,6 +49,6 @@ class PointCloud(Collection):
 
 
     def transform(self, transform:Transform) -> 'PointCloud':        
-        tmp = copy.deepcopy(self)
-        tmp._raw = transform_vertices(self._raw, transform.matrix)
-        return tmp
+        tmp = np.copy(self._raw)
+        tmp = transform_vertices(self._raw, transform.get_matrix())
+        return PointCloud(tmp)
