@@ -22,4 +22,13 @@ def polygon_contains_point(vertices:np.ndarray, x:float, y:float) -> bool:
                         inside = not inside
         p1x,p1y = p2x,p2y
 
-    return inside
\ No newline at end of file
+    return inside
+
+
+
+@numba.njit(cache=True)
+def polygon_contains_all_vertices(poly_vertices:np.ndarray, vertices:np.ndarray) -> bool:
+    for v in vertices[:,:2]:
+        if not polygon_contains_point(poly_vertices, v[0], v[1]):
+            return False
+    return True
