@@ -23,7 +23,7 @@ class Point(Geometry):
 
 
     def transform(self, transform:'Transform') -> 'Point':
-        return Point(*transform_point(self.x, self.y, self.z, transform.matrix))
+        return Point(*transform_point(self.x, self.y, self.z, transform.get_matrix()))
 
 
     def __add__(self, other:'Point') -> 'Point':
