@@ -37,7 +37,7 @@ class Polygon(Geometry):
 
 
     def transform(self, transform:'Transform') -> 'Polygon':
-        return Polygon(transform_vertices(self.vertices, transform.matrix))
+        return Polygon(transform_vertices(self.vertices, transform.get_matrix()))
 
 
     @classmethod
