@@ -1,6 +1,7 @@
 from openride.core.geometry import Geometry
 from openride.core.numba.interpolation import linear_interpolation
-from openride.core.numba.polyline_utils import distance_to_index, index_to_distance, vertices_to_distances
+from openride.core.numba.polyline_utils import distance_to_index, index_to_distance, resample_linear, tangent_angles
+from openride.core.numba.polyline_utils import radius_of_curvature, vertices_to_distances
 from openride.core.numba.transforms import transform_vertices
 from openride.core.point import Point
 
@@ -9,7 +10,7 @@ import numpy as np
 
 from dataclasses import dataclass
 from shapely import geometry
-from typing import Union, List, TYPE_CHECKING
+from typing import Tuple, Union, List, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from openride.core.transform import Transform
@@ -37,7 +38,7 @@ class Polyline(Geometry):
 
 
     def transform(self, transform:'Transform') -> 'Polyline':
-        return Polyline(transform_vertices(self.vertices, transform.matrix))
+        return Polyline(transform_vertices(self.vertices, transform.get_matrix()))
 
 
     def __len__(self) -> int:
@@ -92,3 +93,20 @@ class Polyline(Geometry):
             y = linear_interpolation(self.vertices[:,1], key)
             z = linear_interpolation(self.vertices[:,2], key)
             return Point(x, y, z)
+
+
+    def get_tangent_angles(self) -> np.ndarray:
+        return tangent_angles(self.vertices)
+
+
+    def get_radius_of_curvature(self) -> np.ndarray:
+        return radius_of_curvature(self.vertices)
+
+
+    def resample(self, delta:float, return_indices:bool=False) -> Union['Polyline', Tuple['Polyline', np.ndarray]]:
+        N = int(self.get_total_distance() / delta + 0.5) + 1
+        resampled_vertices, indices = resample_linear(self.vertices, N)
+        resampled = Polyline(resampled_vertices)
+        if return_indices:
+            return resampled, indices
+        return resampled
