@@ -20,8 +20,7 @@ class Rotation:
         self.yaw = self.yaw % (2*np.pi)
 
 
-    @property
-    def matrix(self) -> np.ndarray:
+    def get_matrix(self) -> np.ndarray:
         return rotation_matrix(self.roll, self.pitch, self.yaw)
 
 
