@@ -2,12 +2,16 @@ from openride import PointCloud
 from openride.core.point import Point
 from openride.core.rotation import Rotation
 from openride.core.transform import Transform
+from openride.test import get_pytest_benchmark
 
 import numpy as np
 import pytest
 
 
 
+pytest_benchmark = get_pytest_benchmark(group="core.collections.point_cloud")
+
+
 def test_init_empty():
     pc = PointCloud()
     assert len(pc) == 0
@@ -43,15 +47,18 @@ def test_repr():
     assert isinstance(str(pc), str)
 
 
-def test_getitem():
+@pytest_benchmark
+def test_getitem(benchmark):
     pc = PointCloud([Point(), Point(1)])
-    point = pc[1]
+    point = benchmark(pc.__getitem__, 1)
     assert point.x == 1
 
 
-def test_transform():
-    pc = PointCloud([Point(), Point()])
-    pc = pc.transform(Transform(Point(1), Rotation(0,0,np.pi)))
+@pytest_benchmark
+def test_transform(benchmark):
+    pc = PointCloud([Point() for _ in range(10000)])
+    tf = Transform(Point(1), Rotation(0,0,np.pi))
+    pc = benchmark(pc.transform, tf)
     assert pytest.approx(pc[0].x) == -1
 
 
