@@ -17,7 +17,7 @@ def test_post_init():
 
 def test_rotation_matrix_identity():
     r = Rotation(0,0,0)
-    assert np.all(r.matrix == np.eye(3))
+    assert np.all(r.get_matrix() == np.eye(3))
 
 
 def test_rotation_from_identity():
@@ -28,8 +28,8 @@ def test_rotation_from_identity():
 def test_rotation_euler_matrix_reciprocal():
     for _ in range(10):
         r1 = Rotation(*np.random.random(3)*2*np.pi)
-        r2 = Rotation.from_matrix(r1.matrix)
-        assert np.all(pytest.approx(r1.matrix) == r2.matrix)
+        r2 = Rotation.from_matrix(r1.get_matrix())
+        assert np.all(pytest.approx(r1.get_matrix()) == r2.get_matrix())
 
 
 def test_add_rotations():
